@@ -28,7 +28,7 @@ DEFAULT_PRINTER_ATTRIBUTES = [
     "printer-make-and-model",
     "printer-state",
     "printer-state-message",
-    "printer-state-reason",
+    "printer-state-reasons",
     "printer-supply",
     "printer-up-time",
     "printer-uri-supported",
